@@ -20,6 +20,7 @@
 
 # pylint: disable=bad-indentation
 
+import re
 import typing
 
 import dateutil.parser
@@ -115,7 +116,7 @@ class Item:
   def __str__(self) -> str:
     return '<{0} - {1} : {2}>'.format(self.type_, self.name, self._state)
 
-  def update(self, value: typing.Any):
+  def update(self, value: typing.Any) -> None:
     """Updates the state of an item.
 
     Args:
@@ -127,10 +128,10 @@ class Item:
     v = self._rest_format(value)
 
     # noinspection PyTypeChecker
-    self.openhab.req_put('/items/' + self.name + '/state', data=v)
+    self.openhab.req_put('/items/{}/state'.format(self.name), data=v)
 
   # noinspection PyTypeChecker
-  def command(self, value: typing.Any):
+  def command(self, value: typing.Any) -> None:
     """Sends the given value as command to the event bus.
 
     Args:
@@ -141,7 +142,7 @@ class Item:
 
     v = self._rest_format(value)
 
-    self.openhab.req_post('/items/' + self.name, data=v)
+    self.openhab.req_post('/items/{}'.format(self.name), data=v)
 
 
 class DateTimeItem(Item):
@@ -181,7 +182,8 @@ class DateTimeItem(Item):
     Returns:
       str: The string as converted from the datetime.datetime parameter.
     """
-    return value.isoformat()
+    # openHAB supports only up to milliseconds as of this writing
+    return value.isoformat(timespec='milliseconds')
 
 
 class SwitchItem(Item):
@@ -202,7 +204,7 @@ class NumberItem(Item):
   types = [openhab.types.DecimalType]
 
   def _parse_rest(self, value):
-    """Parse a REST result into a native object
+    """Parse a REST result into a native object.
 
     Args:
       value (str): A string argument to be converted into a float object.
@@ -210,7 +212,14 @@ class NumberItem(Item):
     Returns:
       float: The float object as converted from the string parameter.
     """
-    return float(value)
+    # Items of type NumberItem may contain units of measurement. Here we make sure to strip them off.
+    # @TODO possibly implement supporting UoM data for NumberItems not sure this would be useful.
+    m = re.match(r'''^(-?[0-9.]+)''', value)
+
+    if m:
+      return float(m.group(1))
+
+    raise ValueError('{}: unable to parse value "{}"'.format(self.__class__, value))
 
   def _rest_format(self, value):
     """Format a value before submitting to openHAB
@@ -225,9 +234,13 @@ class NumberItem(Item):
 
 
 class ContactItem(Item):
-  """Contact item type"""
+  """Contact item type."""
   types = [openhab.types.OpenCloseType]
 
+  def command(self, *args, **kwargs):
+    """This overrides the `Item` command method. Commands are not accepted for items of type contact!"""
+    raise ValueError('This item ({}) only supports updates, not commands!'.format(self.__class__))
+
   def open(self):
     """Set the state of the contact item to OPEN"""
     self.state = 'OPEN'
